@@ -1,34 +1,41 @@
 from grid.cli.grid_artifacts import artifacts
-from grid.cli.grid_cancel import cancel
+from grid.cli.grid_clusters import clusters
 from grid.cli.grid_credentials import credentials
-from grid.cli.grid_datastores import datastores
+from grid.cli.grid_datastore import datastore
 from grid.cli.grid_delete import delete
+from grid.cli.grid_edit import edit
+from grid.cli.grid_env import sync_env
 from grid.cli.grid_history import history
-from grid.cli.grid_interactive import interactive
 from grid.cli.grid_login import login
 from grid.cli.grid_logs import logs
-from grid.cli.grid_metrics import metrics
-# SLURM
-from grid.cli.grid_slurm import slurm
+from grid.cli.grid_run import run
+from grid.cli.grid_session import session
+
+#from grid.cli.grid_metrics import metrics
 from grid.cli.grid_ssh_keys import ssh_keys
 from grid.cli.grid_status import status
-from grid.cli.grid_train import train
+from grid.cli.grid_stop import stop
+from grid.cli.grid_team import team
+from grid.cli.grid_user import user
 from grid.cli.grid_view import view
 
 __all__ = [
     'view',
     'status',
     'login',
-    'train',
-    'cancel',
+    'run',
+    'stop',
     'credentials',
     'history',
     'logs',
-    'metrics',
-    'interactive',
+    'session',
     'artifacts',
     'delete',
-    'datastores',
-    'slurm',
+    'datastore',
     'ssh_keys',
+    'user',
+    'sync_env',
+    'clusters',
+    'edit',
+    'team',
 ]
