@@ -2,13 +2,14 @@ from typing import Optional
 
 import click
 
+from grid import rich_click
 from grid.client import Grid
 import grid.globals as env
 
 
 @click.option('--username', type=str, help='Username used in Grid')
 @click.option('--key', type=str, help='API Key from Grid')
-@click.command()
+@rich_click.command()
 def login(username: Optional[str] = None, key: Optional[str] = None) -> None:
     """Login into Grid AI."""
     client = Grid(load_local_credentials=False)
