@@ -1,11 +1,12 @@
 import click
 
+from grid import rich_click
 from grid.client import Grid
 
 
-@click.command()
-@click.argument('experiment', type=str, nargs=1)
-@click.argument('metric', type=str, nargs=1)
+@rich_click.command()
+@rich_click.argument('experiment', type=str, nargs=1)
+@rich_click.argument('metric', type=str, nargs=1)
 @click.option('--n_lines', default=10, type=int, help='Number of metrics lines (from the end) to return.')
 def metrics(experiment: str, metric: str, n_lines: int) -> None:
     """Gets metric values from an experiment."""
