@@ -2,6 +2,7 @@ from typing import Optional
 
 import click
 
+from grid import rich_click
 from grid.client import Grid
 import grid.globals as env
 from grid.types import ObservableType
@@ -19,18 +20,24 @@ def _check_is_experiment(ctx, _param, value):
     return value
 
 
-@click.command()
-@click.argument('run', type=str, nargs=1, required=False, callback=_check_is_experiment)
-@click.option('--follow', type=bool, help='Follows Run setup progress in terminal', is_flag=True)
+@rich_click.command()
+@rich_click.argument('run', type=str, nargs=1, required=False, callback=_check_is_experiment)
 @click.option('--details', type=bool, help='Shows Run submission details', is_flag=True)
-@click.option('--export',
-              type=click.Choice(['csv', 'json'], case_sensitive=False),
-              help='Exports status output to supplied file type')
-def status(run: Optional[str] = None,
-           follow: Optional[bool] = False,
-           details: Optional[bool] = False,
-           export: Optional[str] = None) -> None:
-    """Checks the status of Runs and Experiments."""
+@click.option(
+    '--export',
+    type=click.Choice(['csv', 'json'], case_sensitive=False),
+    help='Exports status output to supplied file type'
+)
+@click.option(
+    '--global', 'is_global', type=bool, is_flag=True, help='Fetch status from all collaborators when flag is passed'
+)
+def status(
+    run: Optional[str] = None,
+    details: Optional[bool] = False,
+    export: Optional[str] = None,
+    is_global: Optional[bool] = False
+) -> None:
+    """Checks the status of Runs, Experiments, and Sessions."""
     client = Grid()
 
     # Setup global flag to show build errors with
@@ -46,9 +53,9 @@ def status(run: Optional[str] = None,
         observable = [run]
         kind = ObservableType.EXPERIMENT
 
-    client.status(kind=kind, identifiers=observable, follow=follow, export=export)
+    client.status(kind=kind, identifiers=observable, export=export, is_global=is_global)
 
     # If we have a Run, then don't print the global
     # interactive nodes table.
     if not run:
-        client.status(kind=ObservableType.INTERACTIVE, identifiers=observable, follow=follow, export=export)
+        client.status(kind=ObservableType.INTERACTIVE, identifiers=observable, export=export, is_global=is_global)
