@@ -1,10 +1,9 @@
-from typing import Any, Dict
+from typing import Any, Dict, io
 
 import click
 import yaml
 
-from grid.tracking import Segment
-from grid.tracking import TrackingEvents
+from grid.tracking import Segment, TrackingEvents
 
 DISK_SIZE_ERROR_MSG = "Invalid disk size, should be greater than 100Gb"
 
@@ -26,10 +25,12 @@ def validate_config(cfg: Dict[str, Any]) -> None:
     tracker.send_event(TrackingEvents.CONFIG_PARSED, properties={'config': cfg})
 
 
-def read_config(ctx, param, value):
+def read_config(value: io.TextIO):
     """
-    Click callback that reads value from the config file and fix
-    the structure if it doesn't exist.
+    Parameters
+    ----------
+    value:
+        A TextIO object that has `.read()` defined for it
     """
     grid_config = value
     if grid_config:
@@ -51,6 +52,14 @@ def read_config(ctx, param, value):
     return grid_config
 
 
+def read_config_callback(ctx, param, value):
+    """
+    Click callback that reads value from the config file and fix
+    the structure if it doesn't exist.
+    """
+    return read_config(value)
+
+
 def validate_disk_size_callback(ctx, param, value: int) -> int:
     """
     Validates the disk size upon user input.
