@@ -2,7 +2,7 @@ import subprocess
 from typing import List
 
 
-def execute_git_command(args: List[str]) -> str:
+def execute_git_command(args: List[str], cwd=None) -> str:
     """
     Executes a git command. This is expected to return a
     single string back.
@@ -16,6 +16,7 @@ def execute_git_command(args: List[str]) -> str:
                              stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE,
                              universal_newlines=True,
+                             cwd=None,
                              check=False)
 
     output = process.stdout.strip() + process.stderr.strip()
