@@ -1,5 +1,6 @@
 from grid.core.artifact import Artifact
 from grid.core.experiment import Experiment
 from grid.core.run import Run
+from grid.core.team import Team
 
-__all__ = ["Experiment", "Run", "Artifact"]
+__all__ = ["Experiment", "Run", "Artifact", "Team"]
