@@ -9,8 +9,18 @@ class GridObject:
     common methods and the Grid client instance.
     """
     def __init__(self):
+        self._data = None
         self.client = Grid()
 
+    @property
+    def data(self):
+        return self._data
+
+    @data.setter
+    def data(self, value):
+        self._data = value
+        self._update_meta()
+
     def _update_meta(self) -> None:
         """Updates object attributes with metadata from backend."""
         if not self._data:
