@@ -1,5 +1,4 @@
-from dataclasses import dataclass
-from dataclasses import field
+from dataclasses import dataclass, field
 from enum import Enum
 import json
 import logging
@@ -13,15 +12,23 @@ import uuid
 
 from click.exceptions import ClickException
 from dataclasses_json import dataclass_json
-from gql import Client
-from gql import gql
+from gql import Client, gql
 import requests
 import yaspin
 
-from grid.tar import get_split_size
-from grid.tar import tar_path
-from grid.uploader import S3Uploader
-from grid.uploader import UploadProgressCallback
+from grid.tar import get_split_size, tar_path
+from grid.uploader import S3Uploader, UploadProgressCallback
+
+SUPPORTED_FILE_EXTENSIONS = [".zip", ".tar", ".tar.gz"]
+
+
+def find_supported_extension(path_or_url: str) -> Optional[str]:
+    """Returns the supported extension if exists"""
+    for extension in SUPPORTED_FILE_EXTENSIONS:
+        if path_or_url.endswith(extension):
+            return extension
+
+    return None
 
 
 def check_source(source: str):
@@ -29,15 +36,13 @@ def check_source(source: str):
     Check if the source is a valid source for datastore
     """
     if source.startswith("http"):
-        supported_extensions = [".zip", ".tar.gz", ".tar"]
-
-        valid_extension = any(source.endswith(extension) for extension in supported_extensions)
-
-        if valid_extension is False:
-            raise ClickException(f"""
+        if not find_supported_extension(source):
+            raise ClickException(
+                f"""
                 Grid currently only supports remote files with the
-                following extensions: {supported_extensions}
-                """)
+                following extensions: {SUPPORTED_FILE_EXTENSIONS}
+                """
+            )
 
         # Check if url is accessible
         status = requests.head(source, allow_redirects=True)
@@ -45,28 +50,48 @@ def check_source(source: str):
             raise ClickException(f"Source url {source} is not reachable")
         return
 
-    if os.path.exists(source) is False:
-        raise ClickException(f"Source local directory path {source} doesn't exist")
+    source_path = Path(source)
+    if source_path.exists() is False:
+        raise ClickException(f"Source local path {source} doesn't exist")
+
+    if source_path.is_file():
+        if not find_supported_extension(source):
+            raise ClickException(
+                f"""
+                Grid currently only supports local file upload with the
+                following extensions: {SUPPORTED_FILE_EXTENSIONS}
+                """
+            )
+        return
+
+    if not source_path.is_dir():
+        raise ClickException(
+            f"""
+             Grid currently only supports local sources that are either
+             a compressed file or directory.
+        """
+        )
 
 
-def create_datastore(name: str, credential_id: str, client: Client, remote_source_url: Optional[str] = None):
+def create_datastore(name: str, credential_id: str, client: Client, source: str = None):
     """Create datastore in Grid"""
 
     # Create Grid datastore directly in Grid without uploading,
     # since Grid will handle extraction and creating a optimizted
     # datastore automatically.
 
-    mutation = gql("""
+    mutation = gql(
+        """
     mutation (
         $name: String!
         $credentialId: String!
-        $remoteSourceUrl: String
+        $source: String
         ) {
         createDatastore (
             properties: {
                     name: $name
                     credentialId: $credentialId
-                    remoteSourceUrl: $remoteSourceUrl
+                    source: $source
                 }
         ) {
         success
@@ -75,9 +100,10 @@ def create_datastore(name: str, credential_id: str, client: Client, remote_sourc
         datastoreVersion
         }
     }
-    """)
+    """
+    )
 
-    params = {'name': name, 'credentialId': credential_id, 'remoteSourceUrl': remote_source_url}
+    params = {'name': name, 'credentialId': credential_id, 'source': source}
 
     result = client.execute(mutation, variable_values=params)
     success = result['createDatastore']['success']
@@ -144,10 +170,9 @@ class DatastoreRemoteUpload:
         spinner.start()
 
         try:
-            create_datastore(name=self.name,
-                             credential_id=self.credential_id,
-                             client=self.client,
-                             remote_source_url=self.source_url)
+            create_datastore(
+                name=self.name, credential_id=self.credential_id, client=self.client, source=self.source_url
+            )
         except Exception as e:
             spinner.text = "Failed to create datastore"
             spinner.fail("✘")
@@ -271,8 +296,10 @@ class DatastoreUploadSession(UploadProgressCallback):
                 name = content["name"]
                 version = content["version"]
                 session_name = f"{name}-v{version}"
-                raise UnsupportedDatastoreImplementationError(f"Incomplete datastore session {session_name} is no " +
-                                                              "longer supported. Please restart this upload.")
+                raise UnsupportedDatastoreImplementationError(
+                    f"Incomplete datastore session {session_name} is no " +
+                    "longer supported. Please restart this upload."
+                )
 
             session = DatastoreUploadSession.from_dict(content)
 
@@ -297,7 +324,8 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         self._update_progress("Requesting presigned URLs from Grid...")
 
-        query = gql("""
+        query = gql(
+            """
         query GetMultiPartPresignedUrls (
             $path: String!,
             $datastoreId: ID!,
@@ -315,13 +343,14 @@ class DatastoreUploadSession(UploadProgressCallback):
                 }
             }
         }
-        """)
+        """
+        )
         params = {
             'datastoreId': self.id,
             'count': self.part_count,
             # TODO: This is going to change once we implement
             # a new tarring scheme, so hardcoding the path here for now.
-            'path': "data.tar.gz"
+            'path': self.uploaded_target_file
         }
 
         result = self.client.execute(query, variable_values=params)
@@ -338,17 +367,46 @@ class DatastoreUploadSession(UploadProgressCallback):
     @property
     def target_file(self) -> str:
         """Get target compressed data file"""
-        return os.path.join(self.session_path, "data.tar.gz")
+        source_path = Path(self.source_dir)
+        if source_path.is_dir():
+            return os.path.join(self.session_path, "data.tar.gz")
+        else:
+            return self.source_dir
+
+    @property
+    def uploaded_target_file(self) -> str:
+        """The target file name we will upload into S3"""
+        source_path = Path(self.source_dir)
+        if source_path.is_dir():
+            # Since we're compressing the directory ourselves, we know
+            # the file name is ending with .tar.gz
+            return "data.tar.gz"
+        else:
+            extension = find_supported_extension(self.source_dir)
+            return f"data{extension}"
 
     def _create_datastore(self):
         self._update_progress("Creating datastore in Grid...")
-        datastore_id, datastore_version = create_datastore(name=self.name,
-                                                           credential_id=self.credential_id,
-                                                           client=self.client)
+        datastore_id, datastore_version = create_datastore(
+            name=self.name, credential_id=self.credential_id, client=self.client, source=self.uploaded_target_file
+        )
         self.id = datastore_id
         self.version = datastore_version
 
-    def _compress_source_directory(self):
+    def _compress_source(self):
+        source_path = Path(self.source_dir)
+        if source_path.is_file():
+            # We assume we already checked that the file is a compressed archive.
+            # Skip compressing
+            # We don't know the uncompressed size, so leaving it None so we can compute it
+            # online.
+            self.original_size = 0
+            self.compressed_size = source_path.stat().st_size
+            split_size = get_split_size(self.compressed_size)
+            self.part_count = math.ceil(self.compressed_size / split_size)
+            return
+
+        # Source is a directory, compress it into a tar file.
         if self.compression:
             self._update_progress(f"Packaging and compressing datastore {self.name}...")
         else:
@@ -371,13 +429,15 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         split_size = get_split_size(size)
 
-        return S3Uploader(source_file=self.target_file,
-                          presigned_urls=presigned_urls,
-                          already_uploaded_parts=already_uploaded_parts,
-                          name=f"{self.name}-{self.version}",
-                          split_size=split_size,
-                          total_size=size,
-                          progress_callback=self)
+        return S3Uploader(
+            source_file=self.target_file,
+            presigned_urls=presigned_urls,
+            already_uploaded_parts=already_uploaded_parts,
+            name=f"{self.name}-{self.version}",
+            split_size=split_size,
+            total_size=size,
+            progress_callback=self
+        )
 
     def _upload_parts(self):
         self._update_progress(f"Uploading datastore {self.name} (v{self.version}) datastore" + " to S3...")
@@ -393,8 +453,9 @@ class DatastoreUploadSession(UploadProgressCallback):
             else:
                 already_uploaded_parts.append(part)
 
-        uploader = self._create_uploader(presigned_urls=unuploaded_presigned_urls,
-                                         already_uploaded_parts=already_uploaded_parts)
+        uploader = self._create_uploader(
+            presigned_urls=unuploaded_presigned_urls, already_uploaded_parts=already_uploaded_parts
+        )
 
         # Stoping and starting the spinner, as the progress bar
         # in uploader will conflict with the spinner
@@ -409,7 +470,8 @@ class DatastoreUploadSession(UploadProgressCallback):
 
     def _mark_upload_complete(self):
         self._update_progress("Completing multi-part uploads with Grid...")
-        mutation = gql("""
+        mutation = gql(
+            """
         mutation (
             $datastoreId: ID!
             $uploadId: String!
@@ -428,13 +490,14 @@ class DatastoreUploadSession(UploadProgressCallback):
             message
             }
         }
-        """)
+        """
+        )
 
         params = {
             'datastoreId': self.id,
             'uploadId': self.upload_id,
             'parts': json.dumps(self.etags),
-            'path': 'data.tar.gz'
+            'path': self.uploaded_target_file
         }
 
         result = self.client.execute(mutation, variable_values=params)
@@ -445,7 +508,8 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         self._update_progress("Completing datastore upload...")
 
-        mutation = gql("""
+        mutation = gql(
+            """
         mutation (
             $datastoreId: ID!
             $sizeMib: Int!
@@ -460,7 +524,8 @@ class DatastoreUploadSession(UploadProgressCallback):
             message
             }
         }
-        """)
+        """
+        )
 
         params = {'datastoreId': self.id, 'sizeMib': math.ceil(self.original_size / (1024**2))}
 
@@ -498,7 +563,7 @@ class DatastoreUploadSession(UploadProgressCallback):
         self.spinner.start()
 
         steps = [(self._create_datastore, DatastoreUploadSteps.CREATE_DATASTORE),
-                 (self._compress_source_directory, DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY),
+                 (self._compress_source, DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY),
                  (self._get_presigned_urls, DatastoreUploadSteps.GET_PRESIGNED_URLS),
                  (self._upload_parts, DatastoreUploadSteps.UPLOAD_PARTS),
                  (self._mark_upload_complete, DatastoreUploadSteps.MARK_UPLOAD_COMPLETE)]
@@ -528,12 +593,14 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         except InvalidDatastoreError as e:
             self.spinner.fail("✘")
-            self.logger.error(f"""
+            self.logger.error(
+                f"""
             An non-recoverable error occured when uploading datastore
             {self.session_name}.
 
             Please try again or contact Grid for support
-            """)
+            """
+            )
             raise e
         except (Exception, KeyboardInterrupt) as e:
             self.spinner.fail("✘")
@@ -542,7 +609,7 @@ class DatastoreUploadSession(UploadProgressCallback):
 
             To resume, run:
 
-            grid datastores resume {self.session_name}
+            grid datastore resume {self.session_name}
             """
             self.logger.error(message)
             raise e
