@@ -189,7 +189,10 @@ def _get_valid_stem(string: str) -> Optional[str]:
     scheme = get_url_scheme(string).lower()
     if scheme == "file":
         raise RuntimeError(f"Local paths are not portable '{string}'")
-    if scheme and scheme not in ALLOWED_SCHEMES:
+
+    # Windows paths either get parsed as scheme = drive letter (e.g. "C") for absolute paths or as scheme = string for
+    # relative paths. We explicitly filter these cases before checking for a match to ALLOWED_SCHEMES.
+    if scheme and len(scheme) > 1 and scheme != string and scheme not in ALLOWED_SCHEMES:
         raise RuntimeError(f"Valid URL schemes are {ALLOWED_SCHEMES}")
 
     if is_valid_url(string):
@@ -206,9 +209,10 @@ def _get_valid_stem(string: str) -> Optional[str]:
             raise RuntimeError(f"Absolute paths might not resolve '{path}'")
         if path.exists():
             cwd = Path.cwd()
-            absolute = path.resolve()
+            # Use os.path.abspath as an alternative to path.resolve() which doesn't work on Windows.
+            absolute = Path(os.path.abspath(path))
             if cwd not in absolute.parents and cwd != absolute:
-                raise RuntimeError(f"Path outside of current working " f"directory are not portable {path}")
+                raise RuntimeError(f"Paths outside of the current working directory are not portable: {path}")
         else:
             raise RuntimeError(f"Error while parsing {string}")
     return path.resolve().stem.split(".")[0]
@@ -481,6 +485,14 @@ class DependencyManagerBase(abc.ABC):
         """
         raise NotImplementedError
 
+    @property
+    def source_deps(self):
+        if not hasattr(self, "_source_deps_list"):
+            raise RuntimeError("Manager is not ready. Run `_setup()`")
+        if not isinstance(self._source_deps_list, list):
+            raise RuntimeError("Source list is not a valid python list")
+        return self._source_deps_list
+
     def _setup(self):
         self._source_deps_list: List[str] = self._scan_source_deps()
 
@@ -502,6 +514,9 @@ class DependencyManagerBase(abc.ABC):
         if set(self._source_deps_list) - set(self.file_deps):
             return True
         for key in set(self._source_deps_list).intersection(self.env_deps):
+            # TODO this equality check might have issues
+            #  But the only way to make it work is to deploy in the wild
+            #  and take feedback
             try:
                 if self.env_deps[key] != self.file_deps[key]:
                     return True
@@ -527,10 +542,9 @@ class DependencyManagerBase(abc.ABC):
 
         # TODO: remove pipreqs dependency
         # other considerations: pydeps & pigar
-        candidates = pipreqs.get_all_imports(input_path,
-                                             encoding=None,
-                                             extra_ignore_dirs=ignore_dirs,
-                                             follow_links=True)
+        candidates = pipreqs.get_all_imports(
+            input_path, encoding=None, extra_ignore_dirs=ignore_dirs, follow_links=True
+        )
         return [_source2parsed_pypi(c) for c in candidates]
 
     def get_missing(self) -> Collection[str]:
@@ -562,6 +576,7 @@ class DependencyManagerBase(abc.ABC):
         # That might be true for file_deps as well but that's something user
         # gave us explicitly and hence ignoring. Also, valid_names must keep
         # the order of values in requirements file
+
         missing = set(self._source_deps_list) - set(self.file_deps)
         for name in itertools.chain(self.file_deps.keys(), sorted(missing)):
             if name in self.env_deps and name in self.file_deps:
@@ -585,14 +600,18 @@ class DependencyManagerBase(abc.ABC):
             collated.append(qualified)
         return collated
 
-    def write_config(self, config: Dict):
+    def write_config(self, config_path: Optional[str] = None):
         names = set()
         for n in self._source_deps_list:
             names |= set(_get_system_deps(n))
         if names:
-            # TODO: config file path is hardcoded
-            config_file = Path("config.yml")
-            config_file.touch(exist_ok=True)
+            config_path = Path(config_path or "config.yml")
+            if config_path.exists():
+                from grid.cli.utilities import read_config
+                config = read_config(value=config_path.open('r'))
+            else:
+                config = {"compute": {}}
+                config_path.touch()
             # Sorting to make the order deterministic
             sys_deps_action = f"apt install -y {' '.join(sorted(names))}"
             if "actions" not in config["compute"]:
@@ -604,7 +623,7 @@ class DependencyManagerBase(abc.ABC):
                 raise RuntimeError("Parsing error while reading config.yml")
 
             config["compute"]["actions"]["on_image_build"].append(sys_deps_action)
-            yaml.safe_dump(config, config_file.open(mode="w+"))
+            yaml.safe_dump(config, config_path.open(mode="w+"))
 
 
 class CondaManager(DependencyManagerBase):
