@@ -35,6 +35,7 @@ ENVIRONMENT = os.getenv('ENVIRONMENT', 'development')
 
 DEFAULT_GRID_URL = 'https://platform.grid.ai/graphql'
 GRID_URL = get_graphql_url(os.getenv('GRID_URL', DEFAULT_GRID_URL))
+GRID_API_URL = os.getenv('GRID_API_URL', None)
 
 USER_ID = os.getenv('GRID_USER_ID')
 API_KEY = os.getenv('GRID_API_KEY')
@@ -52,3 +53,5 @@ IGNORE_WARNINGS = None
 SKIP_VERSION_CHECK = bool(os.getenv('GRID_SKIP_VERSION_CHECK'))
 
 GRID_SSH_CONFIG = os.getenv("GRID_SSH_CONFIG", default=os.path.join(os.path.expanduser("~"), ".ssh", "config"))
+
+GRID_API_CA_FILE = os.getenv("GRID_API_CA_FILE")
