@@ -69,7 +69,7 @@ class Segment:
         self.client_kwargs['context']['json'] = json.dumps(self.client_kwargs['context'])
         user_id = None
         try:
-            user_id = Grid().user_id
+            user_id = Grid().credentials.user_id
         except click.ClickException:
             pass
 
@@ -101,11 +101,11 @@ class Segment:
         """
         # covers GRID_API_KEY, AWS... etc
         for it in [
-                "ACCESS",
-                "KEY",
-                "PASSWORD",
-                "SECRET",
-                "TOKEN",
+            "ACCESS",
+            "KEY",
+            "PASSWORD",
+            "SECRET",
+            "TOKEN",
         ]:
             if it in key.upper():
                 return True
